
Genedom
=======

.. image:: https://github.com/Edinburgh-Genome-Foundry/genedom/actions/workflows/build.yml/badge.svg
    :target: https://github.com/Edinburgh-Genome-Foundry/genedom/actions/workflows/build.yml
    :alt: GitHub CI build status

.. image:: https://coveralls.io/repos/github/Edinburgh-Genome-Foundry/genedom/badge.svg?branch=master
   :target: https://coveralls.io/github/Edinburgh-Genome-Foundry/genedom?branch=master

GeneDom is a python library for managing the domestication of genetic parts so that they will comply to a genetic assembly standard. It puts together a `sequence optimizer <https://github.com/Edinburgh-Genome-Foundry/DnaChisel>`_, genetic standards data, and a reporting system, to automate the domestication of large batches in an easy and human-friendly way.

Infos
-----

**PIP installation:**

.. code:: bash

  pip install genedom

**Github Page**

`<https://github.com/Edinburgh-Genome-Foundry/genedom>`_


**License:** MIT, Copyright Edinburgh Genome Foundry

More biology software
---------------------

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/Edinburgh-Genome-Foundry.github.io/master/static/imgs/logos/egf-codon-horizontal.png
  :target: https://edinburgh-genome-foundry.github.io/

Genedom is part of the `EGF Codons <https://edinburgh-genome-foundry.github.io/>`_ synthetic biology software suite for DNA design, manufacturing and validation.
